Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(494)

Unified Diff: chrome/browser/ui/cocoa/speech_recognition_window_controller.h

Issue 9568002: Renamed speech input implementation from to speech_recognition_*. The namespace has been renamed fr… (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Rebased from master. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/speech_recognition_window_controller.h
diff --git a/chrome/browser/ui/cocoa/speech_input_window_controller.h b/chrome/browser/ui/cocoa/speech_recognition_window_controller.h
similarity index 58%
rename from chrome/browser/ui/cocoa/speech_input_window_controller.h
rename to chrome/browser/ui/cocoa/speech_recognition_window_controller.h
index c472ecca6f849fa81fb1e7554b23667459bd6da9..5227dc94b092a48155d65619de704cab22770254 100644
--- a/chrome/browser/ui/cocoa/speech_input_window_controller.h
+++ b/chrome/browser/ui/cocoa/speech_recognition_window_controller.h
@@ -1,22 +1,22 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_COCOA_SPEECH_INPUT_WINDOW_CONTROLLER_H_
-#define CHROME_BROWSER_UI_COCOA_SPEECH_INPUT_WINDOW_CONTROLLER_H_
+#ifndef CHROME_BROWSER_UI_COCOA_SPEECH_RECOGNITION_WINDOW_CONTROLLER_H_
+#define CHROME_BROWSER_UI_COCOA_SPEECH_RECOGNITION_WINDOW_CONTROLLER_H_
#pragma once
#import <Cocoa/Cocoa.h>
-#include "chrome/browser/speech/speech_input_bubble.h"
+#include "chrome/browser/speech/speech_recognition_bubble.h"
#include "chrome/browser/ui/cocoa/base_bubble_controller.h"
// Controller for the speech input bubble window. This bubble window gets
// displayed when the user starts speech input in a html input element.
-@interface SpeechInputWindowController : BaseBubbleController {
+@interface SpeechRecognitionWindowController : BaseBubbleController {
@private
- SpeechInputBubble::Delegate* delegate_; // weak.
- SpeechInputBubbleBase::DisplayMode displayMode_;
+ SpeechRecognitionBubble::Delegate* delegate_; // weak.
+ SpeechRecognitionBubbleBase::DisplayMode displayMode_;
// References below are weak, being obtained from the nib.
IBOutlet NSImageView* iconImage_;
@@ -28,7 +28,7 @@
// Initialize the window. |anchoredAt| is in screen coordinates.
- (id)initWithParentWindow:(NSWindow*)parentWindow
- delegate:(SpeechInputBubbleDelegate*)delegate
+ delegate:(SpeechRecognitionBubbleDelegate*)delegate
anchoredAt:(NSPoint)anchoredAt;
// Handler for the cancel button.
@@ -41,23 +41,23 @@
- (IBAction)micSettings:(id)sender;
// Updates the UI with data related to the given display mode.
-- (void)updateLayout:(SpeechInputBubbleBase::DisplayMode)mode
+- (void)updateLayout:(SpeechRecognitionBubbleBase::DisplayMode)mode
messageText:(const string16&)messageText
iconImage:(NSImage*)iconImage;
-// Makes the speech input bubble visible on screen.
+// Makes the speech recognition bubble visible on screen.
- (void)show;
-// Hides the speech input bubble away from screen. This does NOT release the
-// controller and the window.
+// Hides the speech recognition bubble away from screen. This does NOT release
+// the controller and the window.
- (void)hide;
// Sets the image to be displayed in the bubble's status ImageView. A future
// call to updateLayout may change the image.
// TODO(satish): Clean that up and move it into the platform independent
-// SpeechInputBubbleBase class.
+// SpeechRecognitionBubbleBase class.
- (void)setImage:(NSImage*)image;
@end
-#endif // CHROME_BROWSER_UI_COCOA_SPEECH_INPUT_WINDOW_CONTROLLER_H_
+#endif // CHROME_BROWSER_UI_COCOA_SPEECH_RECOGNITION_WINDOW_CONTROLLER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -1,22 +1,22 @@
#include "chrome/browser/ui/cocoa/base_bubble_controller.h"
-// Controller for the speech input bubble window. This bubble window gets
+// Controller for the speech recognition bubble window. This bubble window gets
// displayed when the user starts speech input in a html input element.